@@ -28,26 +28,27 @@ class ElasticSearchCommand(Command):
 
     def execute(self):
         try:
+            response = self._response
+            index = self._index
             if validate_status(self._status_code):
-                response = self._response
                 metadata = response.get('metadata')
                 transaction = metadata.pop('transaction', {})
                 created_at = datetime.datetime.now(tz=CURRENT_TIME_ZONE)
-                index = self._index
                 doc = self._doc
-                args = self._args
                 params = self._params
                 headers = self._headers
                 client = ElasticSearchClient.get_client()
                 elastic_id = metadata.get('id', F"{uuid.uuid4()}-{created_at.timestamp()}")
                 body = {
                     'status': response.get('status'),
-                    'data': self.clean_data_type(response.get('data')),
                     'metadata': metadata,
                     'transaction': self.clean_data_type(transaction),
                     'created_at': created_at,
-                    'args': args
                 }
+                if response.get('data'):
+                    body.update({
+                        'data': self.clean_data_type(response.get('data')),
+                    })
                 if response.get('error'):
                     error = response.get('error')
                     error = {
