@@ -33,7 +33,8 @@ class Bot(telegram.Bot):
         return super(Bot, self).send_message(
             chat_id=chat_id,
             text=text,
-            parse_mode=parse_mode
+            parse_mode=parse_mode,
+            **kwargs,
         )
 
     def send_code(self, chat_id, text):
