@@ -1,6 +1,5 @@
 from django.db import models
 from django.contrib.auth import get_user_model
-from django.contrib.postgres.fields import JSONField
 
 
 class Log(models.Model):
@@ -35,8 +34,8 @@ class Log(models.Model):
 class Report(models.Model):
     index = models.CharField(max_length=1000)
     status = models.PositiveSmallIntegerField()
-    data = JSONField(null=True)
-    text = models.TextField(null=True)
+    data = models.JSONField(null=True, blank=True)
+    text = models.TextField(null=True, blank=True)
     created_at = models.DateTimeField(auto_created=True, auto_now_add=True)
 
     def __str__(self):
